{
  # config,
  lib,
  pkgs,
  ...
}: {
  imports = [
    # Include the results of the hardware scan.
    ./hardware-configuration.nix
  ];

  # ------------ System ------------

  users.users.tacocat = {
    isNormalUser = true;
    extraGroups = ["wheel" "networkmanager" "audio" "video" "bluetooth" "kvm"];
    home = "/home/tacocat";
    description = "Aria Nolan";
  };

  boot.loader = {
    efi.canTouchEfiVariables = false;
    grub = {
      efiSupport = true;
      configurationLimit = 10;
      device = "nodev";
      extraEntries = ''
        menuentry "Void" {
          search --set=void --fs-uuid 987518fa-8ea0-49a6-b1e5-1fed4e4ae50f
          configfile "($void)/boot/grub/grub.cfg"
        }
      '';
    };
  };

  i18n.defaultLocale = "en_US.UTF-8";
  console = {
    font = "Lat2-Terminus16";
    keyMap = "us";
  };

  time.timeZone = "America/New_York";

  networking.hostName = "JWST";
  networking.networkmanager.enable = true;

  # Sound
  sound.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    pulse.enable = true;
    jack.enable = true;
  };

  # Services/Hardware
  hardware.opentabletdriver.enable = true;
  hardware.bluetooth.enable = true;
  services.blueman.enable = true;
  services.printing.enable = true;
  services.geoclue2.enable = true;
  services.mullvad-vpn.enable = true;
  security.rtkit.enable = true;

  services.udev.extraRules = ''
    # 0d28:0204 DAPLink
    SUBSYSTEM=="usb", ATTR{idVendor}=="0d28", ATTR{idProduct}=="0204", MODE:="666"
  '';

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It's perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "23.05"; # Did you read the comment?

  # ------------ Nix ------------

  nix.settings = {
    experimental-features = ["nix-command" "flakes"];
    auto-optimise-store = true;
    trusted-users = ["root" "tacocat"];
  };

  nix.gc = {
    automatic = true;
    dates = "weekly";
    options = "--delete-older-than 1w";
  };

  nixpkgs.config.allowUnfreePredicate = pkg:
    builtins.elem (lib.getName pkg) [
      "steam"
      "steam-original"
      "steam-run"
      "nvidia-x11"
      "nvidia-settings"
      "discord"
      "spotify"
    ];

  programs.nix-index.enable = true;
  programs.command-not-found.enable = false;

  # ------------ Software ------------

  environment = {
    systemPackages = with pkgs; [
      vim
      exfat
      encfs
      ntfs3g
    ];
    # remove nano
    defaultPackages = with pkgs; [
      perl
      rsync
      strace
    ];
  };

  programs.sway = {
    enable = true;
    wrapperFeatures.gtk = true;
    extraPackages = with pkgs; [
      swaylock
      swayidle
      brightnessctl
      wl-mirror
    ];
  };

  programs.waybar.enable = true;
  programs.steam.enable = true;
  programs.steam.remotePlay.openFirewall = true;
  # programs.steam.gamescopeSession =  {
    # enable = true;
    # args = [
    #   "-f"
    #   "--expose-wayland"
    # ];
  # };
  programs.gamemode.enable = true;
  # programs.gamescope.enable = true;

  xdg.portal = {
    enable = true;
    wlr.enable = true;
    extraPortals = with pkgs; [
      xdg-desktop-portal-gtk
    ];
  };

  gtk.iconCache.enable = true;

  # ------------ Graphics ------------

  hardware.opengl = {
    enable = true;
    driSupport = true;
    driSupport32Bit = true;
    extraPackages = with pkgs; [
      intel-compute-runtime
      vaapiVdpau
    ];
  };

  hardware.nvidia = {
    modesetting.enable = true;
    powerManagement.enable = false;
    powerManagement.finegrained = false;
    open = false;
    nvidiaSettings = true;
    prime = {
      offload.enable = true;
      offload.enableOffloadCmd = true;
      intelBusId = "PCI:0:2:0";
      nvidiaBusId = "PCI:1:0:0";
    };
  };

  services.xserver.videoDrivers = ["nvidia"];
}
